此处使用的是 [pymediawiki](https://github.com/barrust/mediawiki) 库的一个异步fork。目前还处于测试阶段，我不保证它在所有情况下都能正常工作。因此我还没有将其单独发布到pypi，而是暂时将其与本插件捆绑分发。

该fork本身依然以MIT许可证授权，仓库地址为：https://github.com/KoishiMoe/pymediawiki-async 。本目录中包含LICENSE文件是为了符合MIT许可证的要求，而本项目（nonebot-plugin-mediawiki）的许可不受其影响。

在测试完善之后，我将会将其单独发布到pypi，并不再与本插件捆绑发布。